@@ -25,7 +25,7 @@
 
 class tst_xdgdesktopfile : public QObject {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
 
     void testRead();
     void testReadLocalized();
